@@ -1,5 +1,5 @@
 /*
-//@line 42 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 42 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
 */
 
 /* This file implements the nsIHelperAppLauncherDialog interface.
@@ -99,9 +99,9 @@ nsUnknownContentTypeDialog.prototype = {
           if (aFolderType != "Downloads")
             throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
         
-//@line 147 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 147 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
           return "Home";
-//@line 150 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 150 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
         }
         
         function getDownloadsFolder(aFolder)
@@ -203,6 +203,10 @@ nsUnknownContentTypeDialog.prototype = {
       if (!aLocalFile || !aLocalFile.exists())
         return null;
 
+      // Remove any leading periods, since we don't want to save hidden files
+      // automatically.
+      aLeafName = aLeafName.replace(/^\.+/, "");
+
       if (aLeafName == "")
         aLeafName = "unnamed" + (aFileExt ? "." + aFileExt : "");
       aLocalFile.append(aLeafName);
@@ -356,7 +360,7 @@ nsUnknownContentTypeDialog.prototype = {
       // want users to be able to autodownload .exe files. 
       var rememberChoice = this.dialogElement("rememberChoice");
 
-//@line 424 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 428 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       var mimeType = this.mLauncher.MIMEInfo.MIMEType;
       if (mimeType == "application/octet-stream" || 
           mimeType == "application/x-msdownload" ||
@@ -491,12 +495,12 @@ nsUnknownContentTypeDialog.prototype = {
         var result;
 
         // The checking is different on Windows...
-//@line 572 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 576 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
             // On other platforms, default is Ok if there is a default app.
             // Note that nsIMIMEInfo providers need to ensure that this holds true
             // on each platform.
         return this.mLauncher.MIMEInfo.hasDefaultHandler;
-//@line 577 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 581 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
     },
     
     // Set "default" application description field.
@@ -517,9 +521,9 @@ nsUnknownContentTypeDialog.prototype = {
 
     // getPath:
     getPath: function (aFile) {
-//@line 600 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 604 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       return aFile.path;
-//@line 602 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 606 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
     },
 
     // initAppAndSaveToDiskValues:
@@ -587,9 +591,9 @@ nsUnknownContentTypeDialog.prototype = {
       }
       
       // otherHandler is always disabled on Mac
-//@line 673 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 677 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       otherHandler.nextSibling.hidden = otherHandler.nextSibling.nextSibling.hidden = false;
-//@line 675 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 679 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       this.updateOKButton();
     },
 
@@ -742,7 +746,7 @@ nsUnknownContentTypeDialog.prototype = {
           // for the file to be saved to to pass to |saveToDisk| - otherwise
           // we must ask the user to pick a save name.
 
-//@line 841 "/usr/obj/ports/mozilla-firefox-1.5.0.11/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 845 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
           this.mLauncher.saveToDisk(null, false);
         }
         else
